==> llm-docs-0.1.2.tgz: package/docs/components/bfcicomponents/verify-custom-image.md <==
---
id: components-bfcicomponents-verify-custom-image
---
# verify-custom-image.sh

This script verifies whether a project's GitLab CI configuration is using the recommended custom Docker image.

## Overview

As part of standardizing CI/CD configurations across Bluefly projects, all projects should use the custom Docker image `registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest`. This script helps identify whether a project is:

1. Using BFCIComponents (preferred)
2. Using the custom Docker image directly
3. Not using the custom Docker image at all

## Usage

```bash
./scripts/verify-custom-image.sh /path/to/project/.gitlab-ci.yml
```

The script will analyze the provided GitLab CI configuration file and output:

- Whether the project is using BFCIComponents
- Whether the project is using the custom Docker image
- Recommendations for improvement

## Example Output

### Project using BFCIComponents with the custom image

```
✓ Project is using BFCIComponents.
✓ Project is using the recommended custom Docker image.

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

### Project using BFCIComponents but disabling the custom image

```
✓ Project is using BFCIComponents.
⚠ The project is explicitly disabling the custom Docker image.
  Consider enabling it with use_custom_image: true

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

### Project not using BFCIComponents or the custom image

```
⚠ Project is not using BFCIComponents.
✗ Project is not using the custom Docker image at all.
  Found 5 image references, but none use the custom image.
  Consider migrating to BFCIComponents or updating image references to:
  image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

## Return Codes

- `0`: Script executed successfully (regardless of Docker image usage status)
- `1`: Invalid arguments or file not found

## Implementation Details

The script checks for:

1. References to BFCIComponents in the configuration file
2. The `use_custom_image` setting if BFCIComponents is used
3. The `custom_image_path` setting if specified
4. Direct image references if BFCIComponents is not used

## Recommended Action

If the script indicates that your project is not using the custom Docker image, follow these steps:

1. If already using BFCIComponents:

   - Set `use_custom_image: true`
   - Use the default image path or specify the correct one

2. If not using BFCIComponents:
   - Use the `migrate-from-bfcommon.sh` script to migrate to BFCIComponents
   - Verify the migration with this script again

==> llm-docs-0.1.4.tgz: package/docs/components/bfcicomponents/verify-custom-image.md <==
---
id: components-bfcicomponents-verify-custom-image
---
# verify-custom-image.sh

This script verifies whether a project's GitLab CI configuration is using the recommended custom Docker image.

## Overview

As part of standardizing CI/CD configurations across LLM Platform projects, all projects should use the custom Docker image `registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest`. This script helps identify whether a project is:

1. Using BFCIComponents (preferred)
2. Using the custom Docker image directly
3. Not using the custom Docker image at all

## Usage

```bash
./scripts/verify-custom-image.sh /path/to/project/.gitlab-ci.yml
```

The script will analyze the provided GitLab CI configuration file and output:

- Whether the project is using BFCIComponents
- Whether the project is using the custom Docker image
- Recommendations for improvement

## Example Output

### Project using BFCIComponents with the custom image

```
✓ Project is using BFCIComponents.
✓ Project is using the recommended custom Docker image.

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

### Project using BFCIComponents but disabling the custom image

```
✓ Project is using BFCIComponents.
⚠ The project is explicitly disabling the custom Docker image.
  Consider enabling it with use_custom_image: true

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

### Project not using BFCIComponents or the custom image

```
⚠ Project is not using BFCIComponents.
✗ Project is not using the custom Docker image at all.
  Found 5 image references, but none use the custom image.
  Consider migrating to BFCIComponents or updating image references to:
  image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest

Recommendations:
1. Migrate to BFCIComponents for standardized CI/CD pipelines
2. Ensure all jobs use the custom Docker image: registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest
3. Include a prepare-ci.sh script to handle local dependencies in CI environments
```

## Return Codes

- `0`: Script executed successfully (regardless of Docker image usage status)
- `1`: Invalid arguments or file not found

## Implementation Details

The script checks for:

1. References to BFCIComponents in the configuration file
2. The `use_custom_image` setting if BFCIComponents is used
3. The `custom_image_path` setting if specified
4. Direct image references if BFCIComponents is not used

## Recommended Action

If the script indicates that your project is not using the custom Docker image, follow these steps:

1. If already using BFCIComponents:

   - Set `use_custom_image: true`
   - Use the default image path or specify the correct one

2. If not using BFCIComponents:
   - Use the `migrate-from-bfcommon.sh` script to migrate to BFCIComponents
   - Verify the migration with this script again
